@@ -33,7 +33,7 @@ import os
 # Local
 from base.g import *
 from base import utils, tui, module
-
+from base.sixext.moves import input
 
 # Console class (from ASPN Python Cookbook)
 # Author:   James Thiele
@@ -52,7 +52,7 @@ class Console(cmd.Cmd):
     # Command definitions
     def do_hist(self, args):
         """Print a list of commands that have been entered"""
-        print self._hist
+        print(self._hist)
 
     def do_exit(self, args):
         """Exits from the console"""
@@ -92,7 +92,7 @@ class Console(cmd.Cmd):
            Despite the claims in the Cmd documentaion, Cmd.postloop() is not a stub.
         """
         cmd.Cmd.postloop(self)   # Clean up command completion
-        print "Exiting..."
+        print("Exiting...")
 
     def precmd(self, line):
         """ This method is called after the line has been input but before
@@ -119,12 +119,12 @@ class Console(cmd.Cmd):
         if not args:
             while True:
                 if alt_text:
-                    nickname = raw_input(log.bold("Enter the name to add to the group (<enter>=done*, c=cancel) ? ")).strip()
+                    nickname = input(log.bold("Enter the name to add to the group (<enter>=done*, c=cancel) ? ")).strip()
                 else:
-                    nickname = raw_input(log.bold("Enter name (c=cancel) ? ")).strip()
+                    nickname = input(log.bold("Enter name (c=cancel) ? ")).strip()
 
                 if nickname.lower() == 'c':
-                    print log.red("Canceled")
+                    print(log.red("Canceled"))
                     return ''
 
                 if not nickname:
@@ -169,13 +169,13 @@ class Console(cmd.Cmd):
         if not args:
             while True:
                 if alt_text:
-                    groupname = raw_input(log.bold("Enter the group to join (<enter>=done*, c=cancel) ? ")).strip()
+                    groupname = input(log.bold("Enter the group to join (<enter>=done*, c=cancel) ? ")).strip()
                 else:
-                    groupname = raw_input(log.bold("Enter the group (c=cancel) ? ")).strip()
+                    groupname = input(log.bold("Enter the group (c=cancel) ? ")).strip()
 
 
                 if groupname.lower() == 'c':
-                    print log.red("Canceled")
+                    print(log.red("Canceled"))
                     return ''
 
                 if not groupname:
@@ -186,7 +186,7 @@ class Console(cmd.Cmd):
                         continue
 
                 if groupname == 'All':
-                    print "Cannot specify group 'All'. Please choose a different group."
+                    print("Cannot specify group 'All'. Please choose a different group.")
                     return ''
 
                 if fail_if_match:
@@ -247,21 +247,21 @@ class Console(cmd.Cmd):
         all_entries = self.db.get_all_records()
         log.debug(all_entries)
 
-        print log.bold("\nNames:\n")
+        print(log.bold("\nNames:\n"))
         if len(all_entries) > 0:
 
             f = tui.Formatter()
             f.header = ("Name", "Fax Number", "Notes", "Member of Group(s)")
-            for name, e in all_entries.items():
+            for name, e in list(all_entries.items()):
                 if not name.startswith('__'):
                     f.add((name, e['fax'], e['notes'], ', '.join(e['groups'])))
 
             f.output()
 
         else:
-            print "(None)"
+            print("(None)")
 
-        print
+        print()
 
     def do_groups(self, args):
         """
@@ -271,7 +271,7 @@ class Console(cmd.Cmd):
         all_groups = self.db.get_all_groups()
         log.debug(all_groups)
 
-        print log.bold("\nGroups:\n")
+        print(log.bold("\nGroups:\n"))
         if len(all_groups):
 
             f = tui.Formatter()
@@ -281,9 +281,9 @@ class Console(cmd.Cmd):
             f.output()
 
         else:
-            print "(None)"
+            print("(None)")
 
-        print
+        print()
 
 
     def do_edit(self, args):
@@ -298,7 +298,7 @@ class Console(cmd.Cmd):
         e = self.db.get(nickname)
         log.debug(e)
 
-        print log.bold("\nEdit/modify information for %s:\n" % nickname)
+        print(log.bold("\nEdit/modify information for %s:\n" % nickname))
 
 #        save_title = e['title']
 #        title = raw_input(log.bold("Title (<enter>='%s', c=cancel) ? " % save_title)).strip()
@@ -336,10 +336,10 @@ class Console(cmd.Cmd):
 
         save_faxnum = e['fax']
         while True:
-            faxnum = raw_input(log.bold("Fax Number (<enter>='%s', c=cancel) ? " % save_faxnum)).strip()
+            faxnum = input(log.bold("Fax Number (<enter>='%s', c=cancel) ? " % save_faxnum)).strip()
 
             if faxnum.lower() == 'c':
-                print log.red("Canceled")
+                print(log.red("Canceled"))
                 return
 
             if not faxnum and not save_faxnum:
@@ -360,17 +360,17 @@ class Console(cmd.Cmd):
             if ok: break
 
         save_notes = e['notes']
-        notes = raw_input(log.bold("Notes (<enter>='%s', c=cancel) ? " % save_notes)).strip()
+        notes = input(log.bold("Notes (<enter>='%s', c=cancel) ? " % save_notes)).strip()
 
         if notes.lower() == 'c':
-            print log.red("Canceled")
+            print(log.red("Canceled"))
             return
 
         if not notes:
             notes = save_notes
 
         if e['groups']:
-            print "\nLeave or Stay in a Group:\n"
+            print("\nLeave or Stay in a Group:\n")
 
         new_groups = []
         for g in e['groups']:
@@ -381,19 +381,19 @@ class Console(cmd.Cmd):
                 choice_prompt="(y=yes* (stay), n=no (leave), c=cancel) ? ")
 
             if not ok:
-                print log.red("Canceled")
+                print(log.red("Canceled"))
                 return
 
             if ans:
                 new_groups.append(g)
 
-        print "\nJoin New Group(s):\n"
+        print("\nJoin New Group(s):\n")
 
         while True:
             add_group = self.get_groupname('', fail_if_match=False, alt_text=True)
 
             if add_group.lower() == 'c':
-                print log.red("Canceled")
+                print(log.red("Canceled"))
                 return
 
             if not add_group:
@@ -407,7 +407,7 @@ class Console(cmd.Cmd):
                     choice_prompt="(y=yes* (new), n=no, c=cancel) ? ")
 
                 if not ok:
-                    print log.red("Canceled")
+                    print(log.red("Canceled"))
                     return
 
                 if not ans:
@@ -422,7 +422,7 @@ class Console(cmd.Cmd):
         self.db.set(nickname, title, firstname, lastname, faxnum, new_groups, notes)
         self.do_show(nickname)
 
-        print
+        print()
 
     do_modify = do_edit
 
@@ -440,7 +440,7 @@ class Console(cmd.Cmd):
 
         new_entries = []
 
-        print "\nExisting Names in Group:\n"
+        print("\nExisting Names in Group:\n")
 
         for e in old_entries:
             if not e.startswith('__'):
@@ -450,19 +450,19 @@ class Console(cmd.Cmd):
                 continue
 
             if not ok:
-                print log.red("Canceled")
+                print(log.red("Canceled"))
                 return
 
             if ans:
                 new_entries.append(e)
 
-        print "\nAdd New Names to Group:\n"
+        print("\nAdd New Names to Group:\n")
 
         while True:
             nickname = self.get_nickname('', fail_if_match=False, alt_text=True)
 
             if nickname.lower() == 'c':
-                print log.red("Canceled")
+                print(log.red("Canceled"))
                 return
 
             if not nickname.lower():
@@ -472,7 +472,7 @@ class Console(cmd.Cmd):
 
         self.db.update_groups(group, new_entries)
 
-        print
+        print()
 
     do_modifygrp = do_editgrp
 
@@ -486,7 +486,7 @@ class Console(cmd.Cmd):
         nickname = self.get_nickname(args, fail_if_match=True)
         if not nickname: return
 
-        print log.bold("\nEnter information for %s:\n" % nickname)
+        print(log.bold("\nEnter information for %s:\n" % nickname))
 
 #        title = raw_input(log.bold("Title (c=cancel) ? ")).strip()
 #
@@ -511,10 +511,10 @@ class Console(cmd.Cmd):
         lastname = ''
 
         while True:
-            faxnum = raw_input(log.bold("Fax Number (c=cancel) ? ")).strip()
+            faxnum = input(log.bold("Fax Number (c=cancel) ? ")).strip()
 
             if faxnum.lower() == 'c':
-                print log.red("Canceled")
+                print(log.red("Canceled"))
                 return
 
             if not faxnum:
@@ -531,33 +531,33 @@ class Console(cmd.Cmd):
 
             if ok: break
 
-        notes = raw_input(log.bold("Notes (c=cancel) ? ")).strip()
+        notes = input(log.bold("Notes (c=cancel) ? ")).strip()
 
         if notes.strip().lower() == 'c':
-            print log.red("Canceled")
+            print(log.red("Canceled"))
             return
 
         groups = []
         all_groups = self.db.get_all_groups()
         while True:
-            add_group = raw_input(log.bold("Member of group (<enter>=done*, c=cancel) ? " )).strip()
+            add_group = input(log.bold("Member of group (<enter>=done*, c=cancel) ? " )).strip()
 
             if add_group.lower() == 'c':
-                print log.red("Canceled")
+                print(log.red("Canceled"))
                 return
 
             if not add_group:
                 break
 
             if add_group == 'All':
-                print log.red("Cannot specify 'All'.")
+                print(log.red("Cannot specify 'All'."))
                 continue
 
             if add_group not in all_groups:
                 log.warn("Group not found.")
 
                 while True:
-                    user_input = raw_input(log.bold("Is this a new group (y=yes*, n=no) ? ")).lower().strip()
+                    user_input = input(log.bold("Is this a new group (y=yes*, n=no) ? ")).lower().strip()
 
                     if user_input not in ['', 'n', 'y']:
                         log.error("Please enter 'y', 'n' or press <enter> for 'yes'.")
@@ -597,7 +597,7 @@ class Console(cmd.Cmd):
             nickname = self.get_nickname('', fail_if_match=False, alt_text=True)
 
             if nickname.lower() == 'c':
-                print log.red("Canceled")
+                print(log.red("Canceled"))
                 return
 
             if not nickname.lower():
@@ -607,7 +607,7 @@ class Console(cmd.Cmd):
 
         self.db.update_groups(group, entries)
 
-        print
+        print()
 
     do_newgrp = do_addgrp
 
@@ -620,19 +620,19 @@ class Console(cmd.Cmd):
         all_entries = self.db.get_all_records()
         log.debug(all_entries)
 
-        print log.bold("\nView all Data:\n")
+        print(log.bold("\nView all Data:\n"))
         if len(all_entries) > 0:
 
             f = tui.Formatter()
             f.header = ("Name", "Fax", "Notes", "Member of Group(s)")
 
-            for name, e in all_entries.items():
+            for name, e in list(all_entries.items()):
                 if not name.startswith('__'):
                     f.add((name, e['fax'], e['notes'], ', '.join(e['groups'])))
 
             f.output()
 
-        print
+        print()
 
 
 
@@ -662,7 +662,7 @@ class Console(cmd.Cmd):
         else:
             log.error("Name not found. Use the 'names' command to view all names.")
 
-        print
+        print()
 
     do_details = do_show
 
@@ -677,7 +677,7 @@ class Console(cmd.Cmd):
 
         self.db.delete(nickname)
 
-        print
+        print()
 
     do_del = do_rm
 
@@ -692,7 +692,7 @@ class Console(cmd.Cmd):
 
         self.db.delete_group(group)
 
-        print
+        print()
 
     do_delgrp = do_rmgrp
 
@@ -735,18 +735,18 @@ class Console(cmd.Cmd):
             elif ext == '.ldif':
                 typ = 'ldif'
             else:
-                head = file(filename, 'r').read(1024).lower()
+                head = open(filename, 'r').read(1024).lower()
                 if 'begin:vcard' in head:
                     typ = 'vcf'
                 else:
                     typ = 'ldif'
 
         if typ == 'ldif':
-            print "Importing from LDIF file %s..." % filename
+            print("Importing from LDIF file %s..." % filename)
             ok, error_str = self.db.import_ldif(filename)
 
         elif typ in ('vcard', 'vcf'):
-            print "Importing from VCF file %s..." % filename
+            print("Importing from VCF file %s..." % filename)
             ok, error_str = self.db.import_vcard(filename)
 
         if not ok:
@@ -754,7 +754,7 @@ class Console(cmd.Cmd):
         else:
             self.do_list('')
 
-        print
+        print()
 
 
 
@@ -855,7 +855,6 @@ if mode == GUI_MODE:
 
         if 1:
             app = QApplication(sys.argv)
-
             fab = FABWindow(None)
             fab.show()
 
