@@ -274,7 +274,6 @@ class CoreInstall(object):
             'package_available' : TYPE_BOOL,
             'package_arch' : TYPE_LIST,
             'open_mdns_port' : TYPE_LIST, # command to use to open mdns multicast port 5353
-            'acl_rules' : TYPE_BOOL, # Use ACL uDEV rules (Ubuntu 9.10+)
             'libdir_path' : TYPE_STRING,
         }
 
@@ -318,7 +317,7 @@ class CoreInstall(object):
         }
 
         # dependencies
-        # 'name': (<required for option>, [<option list>], <display_name>, <check_func>, <runtime/compiletime>), ...
+        # 'name': (<required or option>, [<option list>], <display_name>, <check_func>, <runtime/compiletime>), ...
         # Note: any change to the list of dependencies must be reflected in base/distros.py
         self.dependencies = {
             # Required base packages
@@ -645,6 +644,7 @@ class CoreInstall(object):
                     break
 
             self.distro_version = ver 
+            self.distro_name = name
         else:
             log.warn("Failed to get the distro information.")
             self.distro, self.distro_version = DISTRO_UNKNOWN, '0.0'
@@ -879,20 +879,14 @@ class CoreInstall(object):
             log.debug("Trying to import 'reportlab'...")
             import reportlab
 
-            ver = reportlab.Version
-            try:
-                ver_f = float(ver)
-            except ValueError:
-                log.debug("Can't determine version.")
-                return False
+            ver = str(reportlab.Version)
+            log.debug("Version: %.1s" % ver)
+            if ver >= "2.0":
+                log.debug("Success.")
+                return True
             else:
-                log.debug("Version: %.1f" % ver_f)
-                if ver_f >= 2.0:
-                    log.debug("Success.")
-                    return True
-                else:
-                    return False
-
+                return False
+                
         except ImportError:
             log.debug("Failed.")
             return False
@@ -976,7 +970,7 @@ class CoreInstall(object):
 
 
     def check_python_devel(self):
-        dir_list = glob.glob('/usr/include/python%d*'%sys.version_info[0])
+        dir_list = glob.glob('/usr/local/include/python%d*'%sys.version_info[0])
         Found = False
         for p in dir_list:
               if check_file('Python.h',dir=p):
@@ -1074,9 +1068,8 @@ class CoreInstall(object):
     def check_cupsddk(self):
         log.debug("Checking for cups-ddk...")
         # TODO: Compute these paths some way or another...
-        #return check_tool("/usr/local/libexec/cups/driver/drv list") and os.path.exists("/usr/local/share/cupsddk/include/media.defs")
-        return (check_file('drv', "/usr/local/libexec/cups/driver") or check_file('drv', "/usr/lib64/cups/driver")) and \
-            check_file('media.defs', "/usr/local/share/cupsddk/include")
+        return check_file('media.defs', "/usr/local/share/cups/ppdc/")
+
 
 
     def check_policykit(self):
@@ -1339,9 +1332,6 @@ class CoreInstall(object):
         if self.get_distro_ver_data('cups_path_with_bitness', False) and self.bitness == 64:
             configure_cmd += ' --with-cupsbackenddir=/usr/lib64/cups/backend --with-cupsfilterdir=/usr/lib64/cups/filter'
 
-        if self.get_distro_ver_data('acl_rules', False):
-            configure_cmd += ' --enable-udev-acl-rules'
-
         if self.enable is not None:
             for c in self.enable:
                 configuration[c] = True
@@ -1367,7 +1357,10 @@ class CoreInstall(object):
         configure_cmd += ' --prefix=/usr' 
         configure_cmd += ' --with-hpppddir=%s' % self.ppd_dir
 
-        if self.bitness == 64:
+        libdir_path = self.get_distro_ver_data('libdir_path',False)
+        if libdir_path and self.bitness == 64:
+            configure_cmd += ' --libdir=%s' % (libdir_path)
+        elif self.bitness == 64:
             configure_cmd += ' --libdir=/usr/lib64'
 
         self.ui_toolkit =  self.get_distro_ver_data('ui_toolkit') 
@@ -1498,7 +1491,7 @@ class CoreInstall(object):
                 if cmds:
                     commands_to_run.extend(cmds)
 
-        package_mgr_cmd = self.get_distro_data('package_mgr_cmd')
+        package_mgr_cmd = self.get_distro_ver_data('package_mgr_cmd')
 
         overall_commands_to_run.extend(commands_to_run)
 
@@ -1637,9 +1630,12 @@ class CoreInstall(object):
             x = 1
             for cmd in pre_cmd:
                 status, output = utils.run(cmd, self.passwordObj)
-
-                if status != 0:
-                    log.warn("An error occurred running '%s'" % cmd)
+                if any(['yum' in cmd,'zypper' in cmd,'dnf' in cmd]):
+                    if status == 1:
+                        log.warn("An error occurred running '%s'" % cmd)
+                else:
+                    if status != 0:
+                        log.warn("An error occurred running '%s'" % cmd)
 
                 if callback is not None:
                     callback(cmd, "Pre-depend step %d" % x)
@@ -1715,7 +1711,7 @@ class CoreInstall(object):
 
     def remove_hplip(self, callback=None):
         failed = True
-        hplip_remove_cmd = self.get_distro_data('hplip_remove_cmd')
+        hplip_remove_cmd = self.get_distro_ver_data('hplip_remove_cmd')
         if hplip_remove_cmd:
             if callback is not None:
                 callback(hplip_remove_cmd, "Removing old HPLIP version")
@@ -2081,8 +2077,8 @@ class CoreInstall(object):
 
 
     def install_missing_dependencies(self, mode=INTERACTIVE_MODE, required_dependencies=[],optional_dependencies=[], missing_cmd=[]):     # Move to core_install
-        package_mgr_cmd = self.get_distro_data('package_mgr_cmd')
-        pre_depend_cmd  = self.get_distro_data('pre_depend_cmd')
+        package_mgr_cmd = self.get_distro_ver_data('package_mgr_cmd')
+        pre_depend_cmd  = self.get_distro_ver_data('pre_depend_cmd')
         overall_install_cmds={}
 
         if len(required_dependencies):
