@@ -35,12 +35,13 @@ import getopt
 import signal
 import time
 import operator
+import subprocess
 
 # Local
 from base.g import *
 import base.utils as utils
 from base import device, tui, module
-
+from base.sixext import to_unicode, to_string_utf8
 username = prop.username
 faxnum_list = []
 recipient_list = []
@@ -89,8 +90,11 @@ if not prop.fax_build:
     log.error("Fax is disabled (turned off during build). Exiting")
     sys.exit(1)
 
-printer_name, device_uri = mod.getPrinterName(printer_name, device_uri,
-    filter={'fax-type': (operator.gt, 0)}, back_end_filter=['hpfax'])
+sts, printer_name, device_uri = mod.getPrinterName(printer_name, device_uri,
+         filter={'fax-type': (operator.gt, 0)}, back_end_filter=['hpfax'])
+
+if not sts:
+    sys.exit(1)
 
 if mode == GUI_MODE:
     if ui_toolkit == 'qt3':
@@ -198,7 +202,6 @@ if mode == GUI_MODE:
             sys.exit(1)
 
         app = QApplication(sys.argv)
-
         dlg = SendFaxDialog(None, printer_name, device_uri, mod.args)
         dlg.show()
 
@@ -217,7 +220,10 @@ else: # NON_INTERACTIVE_MODE
         sys.exit(1)
 
     try:
-        import struct, Queue
+        import struct
+        from base.sixext.moves import queue
+        from base.sixext import PY3
+        from base.sixext import  to_unicode
         from prnt import cups
         from base import magic
 
@@ -285,7 +291,7 @@ else: # NON_INTERACTIVE_MODE
                     aa = db.get(a)
                     log.info("%s (fax number: %s)" % (a, aa['fax']))
 
-                print
+                print()
                 sys.exit(1)
 
         for p in recipient_list:
@@ -295,7 +301,7 @@ else: # NON_INTERACTIVE_MODE
                 log.debug("Name=%s Number=%s" % (a['name'], a['fax']))
 
         for p in faxnum_list:
-            phone_num_list.append({'fax': p, 'name': u'Unknown'})
+            phone_num_list.append({'fax': p, 'name': to_unicode('Unknown')})
             log.debug("Number=%s" % p)
 
         log.debug("Phone num list = %s" % phone_num_list)
@@ -305,6 +311,20 @@ else: # NON_INTERACTIVE_MODE
 
         allowable_mime_types = cups.getAllowableMIMETypes()
 
+        stat = ''
+        try :
+            p = subprocess.Popen('getenforce', stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+            stat, err = p.communicate()
+            stat = to_string_utf8(stat)
+        except OSError :
+            pass
+        except :
+            log.exception()
+            sys.exit(1)
+        if stat.strip('\n') == 'Enforcing' :
+            log.error('Unable to add file. Please disable SeLinux.\nEither disable it manually or run hp-doctor from terminal.')
+            sys.exit(0)
+
         for f in mod.args:
             path = os.path.realpath(f)
             log.debug(path)
@@ -329,7 +349,7 @@ else: # NON_INTERACTIVE_MODE
             ppd_file = cups.getPPD(printer_name)
 
             if ppd_file is not None and os.path.exists(ppd_file):
-                if file(ppd_file, 'r').read(8192).find('HP Fax') == -1:
+                if open(ppd_file, 'rb').read(8192).find(b'HP Fax') == -1:
                     log.error("Fax configuration error. The CUPS fax queue for '%s' is incorrectly configured. Please make sure that the CUPS fax queue is configured with the 'HP Fax' Model/Driver." % printer_name)
                     sys.exit(1)
 
@@ -349,14 +369,14 @@ else: # NON_INTERACTIVE_MODE
 
                 if mime_type == 'application/hplip-fax': # .g3
                     log.info("\nPreparing fax file %s..." % f)
-                    fax_file_fd = file(f, 'r')
+                    fax_file_fd = open(f, 'rb')
                     header = fax_file_fd.read(fax.FILE_HEADER_SIZE)
                     fax_file_fd.close()
 
                     mg, version, pages, hort_dpi, vert_dpi, page_size, \
                         resolution, encoding, reserved1, reserved2 = struct.unpack(">8sBIHHBBBII", header)
 
-                    if mg != 'hplip_g3':
+                    if mg != b'hplip_g3':
                         log.error("%s: Invalid file header. Bad magic." % f)
                         sys.exit(1)
 
@@ -393,6 +413,8 @@ else: # NON_INTERACTIVE_MODE
 
                         if printer_state == cups.IPP_PRINTER_STATE_IDLE:
                             log.debug("Printer name = %s file = %s" % (printer_name, path))
+                            path = to_unicode(path, 'utf-8')
+
                             sent_job_id = cups.printFile(printer_name, path, os.path.basename(path))
                             log.info("\nRendering file '%s' (job %d)..." % (path, sent_job_id))
                             log.debug("Job ID=%d" % sent_job_id)
@@ -426,7 +448,8 @@ else: # NON_INTERACTIVE_MODE
 
                         if fax_file:
                             log.debug("Fax file=%s" % fax_file)
-                            title = str(result[5])
+                            #title = str(result[5])
+                            title = result[5]
                             break
 
                         time.sleep(1)
@@ -437,7 +460,7 @@ else: # NON_INTERACTIVE_MODE
                         sys.exit(1)
 
                     # open the rendered file to read the file header
-                    f = file(fax_file, 'r')
+                    f = open(fax_file, 'rb')
                     header = f.read(fax.FILE_HEADER_SIZE)
 
                     if len(header) != fax.FILE_HEADER_SIZE:
@@ -466,12 +489,12 @@ else: # NON_INTERACTIVE_MODE
 
                 try:
                     dev.open()
-                except Error, e:
+                except Error as e:
                     log.warn(e.msg)
 
                 try:
                     dev.queryDevice(quick=True)
-                except Error, e:
+                except Error as e:
                     log.error("Query device error (%s)." % e.msg)
                     dev.error_state = ERROR_STATE_ERROR
 
@@ -490,8 +513,8 @@ else: # NON_INTERACTIVE_MODE
 
                 service.SendEvent(device_uri, printer_name, EVENT_START_FAX_JOB, prop.username, 0, '')
 
-                update_queue = Queue.Queue()
-                event_queue = Queue.Queue()
+                update_queue = queue.Queue()
+                event_queue = queue.Queue()
 
                 log.info("\nSending fax...")
 
@@ -509,7 +532,7 @@ else: # NON_INTERACTIVE_MODE
                         while update_queue.qsize():
                             try:
                                 status, page_num, phone_num = update_queue.get(0)
-                            except Queue.Empty:
+                            except queue.Empty:
                                 break
 
                             if status == fax.STATUS_IDLE:
