@@ -393,16 +393,10 @@ else: # INTERACTIVE_MODE
                 hp_plugin = utils.which('hp-plugin')
                 if hp_plugin:
                     cmd = "hp-plugin -i"
-                    if os.getuid() != 0:
-                        from base import password
-                        PasswordObj = password.Password(INTERACTIVE_MODE)
-                        PasswordObj.clearPassword()
-                        log.info("Enter Password to install the plugin")
-                        cmd = PasswordObj.getAuthCmd()%cmd
 
-                    # su -c '%s' --> su -c 'hp-plugin -i'
                     if os_utils.execute(cmd) != 0:
                         log.error("Failed to install Plugin.")
+                        log.error("The device you are trying to setup requires a binary plug-in. Some functionalities may not work as expected without plug-ins. Please run 'hp-plugin' as normal user to install plug-ins.Visit http://hplipopensource.com for more infomation.")
                         clean_exit(1)
 
         ppds = cups.getSystemPPDs()
@@ -591,11 +585,6 @@ else: # INTERACTIVE_MODE
             log.info("Location: %s" % location)
             log.info("Information: %s" % info)
 
-            log.debug("Restarting CUPS...")
-            status, output = utils.run(services.restart_cups())
-            log.debug("Restart CUPS returned: exit=%d output=%s" % (status, output))
-
-            time.sleep(1)
             if not os.path.exists(print_ppd): # assume foomatic: or some such
                 add_prnt_args = (printer_name, print_uri, location, '', print_ppd, info)
             else:
